==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/WebSliderLabelDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSliderLabelDescription } from "./WebSliderLabelDescription";
/**
 * @hidden
 */
var WebSliderLabelDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebSliderLabelDescriptionMetadata, _super);
    function WebSliderLabelDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSliderLabelDescriptionMetadata.b = function (a) {
        if (WebSliderLabelDescriptionMetadata.a == null) {
            WebSliderLabelDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSliderLabelDescriptionMetadata.c(WebSliderLabelDescriptionMetadata.a);
        }
        if (a.g(WebSliderLabelDescriptionMetadata.a)) {
            return;
        }
        a.s(WebSliderLabelDescriptionMetadata.a);
    };
    WebSliderLabelDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:SliderLabel");
    };
    WebSliderLabelDescriptionMetadata.d = function (a) {
        WebSliderLabelDescriptionMetadata.b(a);
        a.u("WebSliderLabel", function () { return new WebSliderLabelDescription(); });
        a.t("WebSliderLabel", WebSliderLabelDescriptionMetadata.a);
    };
    WebSliderLabelDescriptionMetadata.$t = markType(WebSliderLabelDescriptionMetadata, 'WebSliderLabelDescriptionMetadata');
    WebSliderLabelDescriptionMetadata.a = null;
    return WebSliderLabelDescriptionMetadata;
}(Base));
export { WebSliderLabelDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebSliderLabelDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSliderLabelDescription } from "./WebSliderLabelDescription";
/**
 * @hidden
 */
var WebSliderLabelDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebSliderLabelDescriptionMetadata, _super);
    function WebSliderLabelDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSliderLabelDescriptionMetadata.b = function (a) {
        if (WebSliderLabelDescriptionMetadata.a == null) {
            WebSliderLabelDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSliderLabelDescriptionMetadata.c(WebSliderLabelDescriptionMetadata.a);
        }
        if (a.j(WebSliderLabelDescriptionMetadata.a)) {
            return;
        }
        a.y(WebSliderLabelDescriptionMetadata.a);
    };
    WebSliderLabelDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:SliderLabel");
        a.item("__tagNameWC", "String:igc-slider-label");
    };
    WebSliderLabelDescriptionMetadata.d = function (a) {
        WebSliderLabelDescriptionMetadata.b(a);
        a.aa("WebSliderLabel", function () { return new WebSliderLabelDescription(); });
        a.z("WebSliderLabel", WebSliderLabelDescriptionMetadata.a);
    };
    WebSliderLabelDescriptionMetadata.$t = markType(WebSliderLabelDescriptionMetadata, 'WebSliderLabelDescriptionMetadata');
    WebSliderLabelDescriptionMetadata.a = null;
    return WebSliderLabelDescriptionMetadata;
}(Base));
export { WebSliderLabelDescriptionMetadata };
